@@ -5,9 +5,10 @@
 # No commandline parameters.  All options are set in this file.
 #
 
-#source ~/.profile
-# Top-level keepaway directory  **SET THIS OPTION**
-keepaway_dir=/home/kuhlmann/keepaway-0.4
+# Top-level keepaway directory
+keepaway_dir=`pwd`
+# Top-level rcssjava directory ** SET THIS OPTION **
+rcssjava_dir=~/rcssjava-0.1
 
 ############################################################
 # Keeper options                                           #
@@ -45,6 +46,8 @@ save_client_draw_log=0            # should I save client logged shape info to a
 client_log_dir=$keepaway_dir/logs # top-level client log directory
 client_dir=$keepaway_dir/player   # directory containing player binary
 client=keepaway_player            # name of player binary
+stop_after=-1                     # stop after num episodes
+start_learning_after=-1           # start learning after num episodes
 
 ############################################################
 # Server options                                           #
@@ -68,16 +71,14 @@ sleep_time=8                     # time (in seconds) before starting PlayOn mode
 
 launch_monitor=0                 # should I launch rcssmonitor on startup?
 
-###########################################################################
-# Trainer options  (Note: There is no trainer included with this release) #
-###########################################################################
+###########################################################
+# Trainer options                                         #
+###########################################################
 
 use_trainer=0                    # should I use a trainer instead of server referee?
-save_trainer_log=0               # should I save trainer's log a file?
-trainer_dir=$keepaway_dir/       # directory containing trainer files
-trainer=                         # name of trainer binary/class
-
-# Additional trainer options here
+save_trainer_log=0               # should I save cycle queue to a file?
+launch_trainer_monitor=0         # should I launch trainer monitor on startup?
+trainer="rcssjava.trainer.Trainer"   # name of trainer class
 
 ############################################################
 #                                                          #
@@ -106,12 +107,12 @@ if (( $unrestricted_vision )); then
   vision_opts="$s::visible_angle=360"
 fi
 
-server_opts="$s::port=$port $s::coach_port=$coach_port $s::olcoach_port=$olcoach_port $s::half_time=-1 $s::forbid_kick_off_offside=0 $s::use_offside=0 $s::stamina_inc_max=3500 $s::synch_mode=$synch_mode $keepaway_opts $log_opts $vision_opts $s::coach=$use_trainer"
+server_opts="$s::port=$port $s::coach_port=$coach_port $s::olcoach_port=$olcoach_port $s::half_time=-1 $s::forbid_kick_off_offside=0 $s::use_offside=0 $s::stamina_inc_max=3500 $s::synch_mode=$synch_mode $s::synch_offset=80 $keepaway_opts $log_opts $vision_opts $s::coach=$use_trainer"
 
 keeper_opts="-t keepers -e $keeper_learn -q $keeper_policy"
 taker_opts="-t takers -e $taker_learn -q $taker_policy"
 
-client_opts="-p $port -k $num_keepers -j $num_takers"
+client_opts="-p $port -k $num_keepers -j $num_takers -x $stop_after -y $start_learning_after"
 
 if (( $save_weights && ( $keeper_learn || $taker_learn ) )); then
   echo Creating weights directory: $save_dir
@@ -143,7 +144,7 @@ if (( $save_kwy_log && $use_trainer )); then
 fi
 
 if (( $save_trainer_log && $use_trainer )); then
-  trainer_log_opts="$trainer_log_opts -log $log_dir/$proc_name.log"
+  trainer_log_opts="$trainer_log_opts -queue_file $log_dir/$proc_name.log"
 fi
 
 echo Starting Server....
@@ -200,13 +201,11 @@ sleep 2
 popd
 
 if (( $use_trainer )); then
-  pushd $trainer_dir
-  trcmd_line="$trainer -port $coach_port $trainer_log_opts"
+  trcmd_line="java -cp $rcssjava_dir/rcssjava.jar $trainer -port $coach_port -keepers $num_keepers -width $ka_width -length $ka_length -takers $num_takers -monitor $launch_trainer_monitor $trainer_log_opts"
   echo Starting Trainer...
-  #echo $trcmd_line
+  echo $trcmd_line
   $trcmd_line &
   trainer_pid=$!
-  popd
 fi
 
 if (( $launch_monitor )); then
@@ -219,4 +218,3 @@ if (( $use_trainer )); then
   wait $trainer_pid
   kill -INT $server_pid
 fi
-
