@@ -52,7 +52,6 @@ KeepawayPlayer::KeepawayPlayer( SMDPAgent* sa, ActHandler* act, WorldModel *wm,
   WM->setTeamName( strTeamName );
   WM->setNumKeepers( iNumKeepers );
   WM->setNumTakers( iNumTakers ); 
-  WM->setMoveSpeed( 0 );
   WM->setNewEpisode( false );
   WM->setLastAction( UnknownIntValue );
   m_timeLastSay = -5;
@@ -285,26 +284,6 @@ SoccerCommand KeepawayPlayer::keeper()
     m_timeStartEpisode = WM->getCurrentTime();
   }
 
-  // move keepaway region
-  if ( WM->getMoveSpeed() != 0 ) {
-    int tDiff = WM->getCurrentTime() - m_timeStartEpisode + 1;
-    Rect kr = WM->getKeepawayRect();
-    VecPosition adjust( WM->getMoveSpeed() * tDiff, 0 );
-    VecPosition corner( SS->getKeepawayLength() / 2, SS->getKeepawayWidth() / 2 );
-    if ( ( corner + adjust ).getX() > PITCH_LENGTH / 2 )
-      WM->setKeepawayRect( VecPosition( PITCH_LENGTH / 2 - SS->getKeepawayLength(),
-					-SS->getKeepawayWidth() / 2 ),
-			   VecPosition( PITCH_LENGTH / 2,
-					SS->getKeepawayWidth() / 2 ) );
-    else
-      WM->setKeepawayRect( -corner + adjust, corner + adjust );
-  }
-
-  //gjk
-//   if ( WM->getAgentObjectType() == OBJECT_TEAMMATE_1 &&
-//        WM->getCurrentCycle() % 20 == 15 )
-//     cout << WM->getCurrentCycle() << ": " << WM->getKeepawayRect().getPosCenter() << endl;
-
   LogDraw.logCircle( "ball belief", WM->getBallPos(),
 		     1.1, 11, false, COLOR_RED, 
 		     WM->getConfidence( OBJECT_BALL ) );
@@ -488,7 +467,7 @@ SoccerCommand KeepawayPlayer::taker()
   if ( WM->isBallKickable() &&
        WM->getClosestInSetTo( OBJECT_SET_TEAMMATES, OBJECT_BALL) ==
        WM->getAgentObjectType() ) {
-    ACT->putCommandInQueue( soc = holdBall() );
+    ACT->putCommandInQueue( soc = holdBall( 0.3 ) );
     return soc;
   }  
 
