@@ -91,6 +91,12 @@ class SenseHandler {
   struct      itimerval itv; /*!< timer used to set alarm to send action     */
 #endif
 
+  //*met 8/16/05
+  bool m_bBusySync;
+  int m_iSyncCounter;
+  int iNrLateMessages;
+  int iNrTotalMessages;
+
 public:
   SenseHandler( Connection* c, WorldModel* wm, ServerSettings *ss,
                 PlayerSettings *ps );
@@ -121,6 +127,7 @@ public:
   // utility functions
   bool    readServerParam               ( char *strParam, 
                                           char *strMsg               );
+  bool synchronize( ); //*met 8/16/05
 };
 
 #endif
