@@ -370,8 +370,6 @@ private:
   double dKeepawayWidth;
   double dKeepawayLength;
 
-  Rect rectKeepaway;
-
   // public methods
 public:
   // constructor for ServerSettings class
@@ -666,10 +664,6 @@ public:
   double getKeepawayWidth              (             ) const;
   bool   setKeepawayLength             ( double d    )      ;
   double getKeepawayLength             (             ) const;
-  bool   setKeepawayRect               ( double dWidth,
-					 double dLength    );
-  Rect   getKeepawayRect               (             ) const;
-
 
   // set- and get methods for parameters not in server.conf or player.conf
   bool   setEffortMax                  ( double d    )      ;
