@@ -92,7 +92,7 @@ inline double rint(double x)
     url: http://www.opengroup.org/onlinepubs/007904975/functions/drand48.html*/
 inline double drand48()
 {
-    return ((double)(rand() % 100)) / 100;
+    return (double)rand() % RAND_MAX;
 }
 #endif
 
@@ -883,6 +883,16 @@ public:
 
   double        keeperReward               (                                 );
   int           keeperStateVars            ( double         state[]          );
+  int           keeperStateRangesAndResolutions ( double         ranges[],
+					     double         minValues[],
+					     double         resolutions[],
+					     int            numK,
+					     int            numT             );
+  /* Yaxin: change to keeperStateRangesAndResolutions to remove the dependency for tile coding
+  int           keeperTileWidths           ( double         tileWidths[],
+					     int            numK,
+					     int            numT             );
+  */
 
   void          setMoveSpeed               ( double         speed            );
   double        getMoveSpeed               (                                 );
